Capabilities

Struct Capabilities 

pub struct Capabilities {
Show 42 fields pub additional_module_columns: Option<Vec<ColumnDescriptor>>, pub breakpoint_modes: Option<Vec<BreakpointMode>>, pub completion_trigger_characters: Option<Vec<String>>, pub exception_breakpoint_filters: Option<Vec<ExceptionBreakpointsFilter>>, pub support_suspend_debuggee: Option<bool>, pub support_terminate_debuggee: Option<bool>, pub supported_checksum_algorithms: Option<Vec<ChecksumAlgorithm>>, pub supports_ansistyling: Option<bool>, pub supports_breakpoint_locations_request: Option<bool>, pub supports_cancel_request: Option<bool>, pub supports_clipboard_context: Option<bool>, pub supports_completions_request: Option<bool>, pub supports_conditional_breakpoints: Option<bool>, pub supports_configuration_done_request: Option<bool>, pub supports_data_breakpoint_bytes: Option<bool>, pub supports_data_breakpoints: Option<bool>, pub supports_delayed_stack_trace_loading: Option<bool>, pub supports_disassemble_request: Option<bool>, pub supports_evaluate_for_hovers: Option<bool>, pub supports_exception_filter_options: Option<bool>, pub supports_exception_info_request: Option<bool>, pub supports_exception_options: Option<bool>, pub supports_function_breakpoints: Option<bool>, pub supports_goto_targets_request: Option<bool>, pub supports_hit_conditional_breakpoints: Option<bool>, pub supports_instruction_breakpoints: Option<bool>, pub supports_loaded_sources_request: Option<bool>, pub supports_log_points: Option<bool>, pub supports_modules_request: Option<bool>, pub supports_read_memory_request: Option<bool>, pub supports_restart_frame: Option<bool>, pub supports_restart_request: Option<bool>, pub supports_set_expression: Option<bool>, pub supports_set_variable: Option<bool>, pub supports_single_thread_execution_requests: Option<bool>, pub supports_step_back: Option<bool>, pub supports_step_in_targets_request: Option<bool>, pub supports_stepping_granularity: Option<bool>, pub supports_terminate_request: Option<bool>, pub supports_terminate_threads_request: Option<bool>, pub supports_value_formatting_options: Option<bool>, pub supports_write_memory_request: Option<bool>,
}
Information about the capabilities of a debug adapter.

Fields

additional_module_columns: Option<Vec<ColumnDescriptor>>

The set of additional module information exposed by the debug adapter.

breakpoint_modes: Option<Vec<BreakpointMode>>

Modes of breakpoints supported by the debug adapter, such as ‘hardware’ or ‘software’. If present, the client may allow the user to select a mode and include it in its setBreakpoints request.

Clients may present the first applicable mode in this array as the ‘default’ mode in gestures that set breakpoints.

completion_trigger_characters: Option<Vec<String>>

The set of characters that should trigger completion in a REPL. If not specified, the UI should assume the . character.

exception_breakpoint_filters: Option<Vec<ExceptionBreakpointsFilter>>

Available exception filter options for the setExceptionBreakpoints request.

support_suspend_debuggee: Option<bool>

The debug adapter supports the suspendDebuggee attribute on the disconnect request.

support_terminate_debuggee: Option<bool>

The debug adapter supports the terminateDebuggee attribute on the disconnect request.

supported_checksum_algorithms: Option<Vec<ChecksumAlgorithm>>

Checksum algorithms supported by the debug adapter.

supports_ansistyling: Option<bool>

The debug adapter supports ANSI escape sequences in styling of OutputEvent.output and Variable.value fields.

supports_breakpoint_locations_request: Option<bool>

The debug adapter supports the breakpointLocations request.

supports_cancel_request: Option<bool>

The debug adapter supports the cancel request.

supports_clipboard_context: Option<bool>

The debug adapter supports the clipboard context value in the evaluate request.

supports_completions_request: Option<bool>

The debug adapter supports the completions request.

supports_conditional_breakpoints: Option<bool>

The debug adapter supports conditional breakpoints.

supports_configuration_done_request: Option<bool>

The debug adapter supports the configurationDone request.

supports_data_breakpoint_bytes: Option<bool>

The debug adapter supports the asAddress and bytes fields in the dataBreakpointInfo request.

supports_data_breakpoints: Option<bool>

The debug adapter supports data breakpoints.

supports_delayed_stack_trace_loading: Option<bool>

The debug adapter supports the delayed loading of parts of the stack, which requires that both the startFrame and levels arguments and the totalFrames result of the stackTrace request are supported.

supports_disassemble_request: Option<bool>

The debug adapter supports the disassemble request.

supports_evaluate_for_hovers: Option<bool>

The debug adapter supports a (side effect free) evaluate request for data hovers.

supports_exception_filter_options: Option<bool>

The debug adapter supports filterOptions as an argument on the setExceptionBreakpoints request.

supports_exception_info_request: Option<bool>

The debug adapter supports the exceptionInfo request.

supports_exception_options: Option<bool>

The debug adapter supports exceptionOptions on the setExceptionBreakpoints request.

supports_function_breakpoints: Option<bool>

The debug adapter supports function breakpoints.

supports_goto_targets_request: Option<bool>

The debug adapter supports the gotoTargets request.

supports_hit_conditional_breakpoints: Option<bool>

The debug adapter supports breakpoints that break execution after a specified number of hits.

supports_instruction_breakpoints: Option<bool>

The debug adapter supports adding breakpoints based on instruction references.

supports_loaded_sources_request: Option<bool>

The debug adapter supports the loadedSources request.

supports_log_points: Option<bool>

The debug adapter supports log points by interpreting the logMessage attribute of the SourceBreakpoint.

supports_modules_request: Option<bool>

The debug adapter supports the modules request.

supports_read_memory_request: Option<bool>

The debug adapter supports the readMemory request.

supports_restart_frame: Option<bool>

The debug adapter supports restarting a frame.

supports_restart_request: Option<bool>

The debug adapter supports the restart request. In this case a client should not implement restart by terminating and relaunching the adapter but by calling the restart request.

supports_set_expression: Option<bool>

The debug adapter supports the setExpression request.

supports_set_variable: Option<bool>

The debug adapter supports setting a variable to a value.

supports_single_thread_execution_requests: Option<bool>

The debug adapter supports the singleThread property on the execution requests (continue, next, stepIn, stepOut, reverseContinue, stepBack).

supports_step_back: Option<bool>

The debug adapter supports stepping back via the stepBack and reverseContinue requests.

supports_step_in_targets_request: Option<bool>

The debug adapter supports the stepInTargets request.

supports_stepping_granularity: Option<bool>

The debug adapter supports stepping granularities (argument granularity) for the stepping requests.

supports_terminate_request: Option<bool>

The debug adapter supports the terminate request.

supports_terminate_threads_request: Option<bool>

The debug adapter supports the terminateThreads request.

supports_value_formatting_options: Option<bool>

The debug adapter supports a format attribute on the stackTrace, variables, and evaluate requests.

supports_write_memory_request: Option<bool>

The debug adapter supports the writeMemory request.