pub struct EvaluateArguments {
pub column: Option<u32>,
pub context: Option<EvaluateArgumentsContext>,
pub expression: String,
pub format: Option<ValueFormat>,
pub frame_id: Option<u64>,
pub line: Option<u32>,
pub source: Option<Source>,
}Expand description
Arguments for evaluate request.
Fields
column: Option<u32>The contextual column where the expression should be evaluated. This may be provided if line is also provided.
It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based.
context: Option<EvaluateArgumentsContext>The context in which the evaluate request is used.
expression: StringThe expression to evaluate.
format: Option<ValueFormat>Specifies details on how to format the result.
The attribute is only honored by a debug adapter if the corresponding capability supportsValueFormattingOptions is true.
frame_id: Option<u64>Evaluate the expression in the scope of this stack frame. If not specified, the expression is evaluated in the global scope.
line: Option<u32>The contextual line where the expression should be evaluated. In the ‘hover’ context, this should be set to the start of the expression being hovered.
source: Option<Source>The contextual source in which the line is found. This must be provided if line is provided.