pub struct ExceptionBreakpointsFilter {
pub condition_description: Option<String>,
pub default: Option<bool>,
pub description: Option<String>,
pub filter: String,
pub label: String,
pub supports_condition: Option<bool>,
}Expand description
An ExceptionBreakpointsFilter is shown in the UI as an filter option for configuring how exceptions are dealt with.
Fields
condition_description: Option<String>A help text providing information about the condition. This string is shown as the placeholder text for a text box and can be translated.
default: Option<bool>Initial value of the filter option. If not specified a value false is assumed.
description: Option<String>A help text providing additional information about the exception filter. This string is typically shown as a hover and can be translated.
filter: StringThe internal ID of the filter option. This value is passed to the setExceptionBreakpoints request.
label: StringThe name of the filter option. This is shown in the UI.
supports_condition: Option<bool>Controls whether a condition can be specified for this filter option. If false or missing, a condition can not be set.