pub struct ModuleEvent {
pub module: Module,
pub reason: ModuleEventReason,
}Expand description
The event indicates that some information about a module has changed.
Fields
module: ModuleThe new, changed, or removed module. In case of removed only the module id is used.
reason: ModuleEventReasonThe reason for the event.