Scope

Struct Scope 

pub struct Scope {
    pub column: Option<u32>,
    pub end_column: Option<u32>,
    pub end_line: Option<u32>,
    pub expensive: bool,
    pub indexed_variables: Option<u32>,
    pub line: Option<u32>,
    pub name: String,
    pub named_variables: Option<u32>,
    pub presentation_hint: Option<ScopePresentationHint>,
    pub source: Option<Source>,
    pub variables_reference: u32,
}
A Scope is a named container for variables. Optionally a scope can map to a source or a range within a source.

Fields

column: Option<u32>

Start position of the range covered by the scope. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based.

end_column: Option<u32>

End position of the range covered by the scope. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based.

end_line: Option<u32>

The end line of the range covered by this scope.

expensive: bool

If true, the number of variables in this scope is large or expensive to retrieve.

indexed_variables: Option<u32>

The number of indexed variables in this scope. The client can use this information to present the variables in a paged UI and fetch them in chunks.

line: Option<u32>

The start line of the range covered by this scope.

name: String

Name of the scope such as ‘Arguments’, ‘Locals’, or ‘Registers’. This string is shown in the UI as is and can be translated.

named_variables: Option<u32>

The number of named variables in this scope. The client can use this information to present the variables in a paged UI and fetch them in chunks.

presentation_hint: Option<ScopePresentationHint>

A hint for how to present this scope in the UI. If this attribute is missing, the scope is shown with a generic UI.

source: Option<Source>

The source for this scope.

variables_reference: u32

The variables of this scope can be retrieved by passing the value of variablesReference to the variables request as long as execution remains suspended. See ‘Lifetime of Object References’ in the Overview section for details.