pub struct SetFunctionBreakpointsResponse {
pub breakpoints: Vec<Breakpoint>,
}Expand description
Response to setFunctionBreakpoints request.
Returned is information about each breakpoint created by this request.
Fields
breakpoints: Vec<Breakpoint>Information about the breakpoints. The array elements correspond to the elements of the breakpoints array.