SetVariableResponse

Struct SetVariableResponse 

pub struct SetVariableResponse {
    pub indexed_variables: Option<u32>,
    pub memory_reference: Option<String>,
    pub named_variables: Option<u32>,
    pub ty: Option<String>,
    pub value: String,
    pub value_location_reference: Option<u64>,
    pub variables_reference: Option<u32>,
}
Response to setVariable request.

Fields

indexed_variables: Option<u32>

The number of indexed child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).

memory_reference: Option<String>

A memory reference to a location appropriate for this result. For pointer type eval results, this is generally a reference to the memory address contained in the pointer. This attribute may be returned by a debug adapter if corresponding capability supportsMemoryReferences is true.

named_variables: Option<u32>

The number of named child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).

ty: Option<String>

The type of the new value. Typically shown in the UI when hovering over the value.

value: String

The new value of the variable.

value_location_reference: Option<u64>

A reference that allows the client to request the location where the new value is declared. For example, if the new value is function pointer, the adapter may be able to look up the function’s location. This should be present only if the adapter is likely to be able to resolve the location.

This reference shares the same lifetime as the variablesReference. See ‘Lifetime of Object References’ in the Overview section for details.

variables_reference: Option<u32>

If variablesReference is > 0, the new value is structured and its children can be retrieved by passing variablesReference to the variables request as long as execution remains suspended. See ‘Lifetime of Object References’ in the Overview section for details.

If this property is included in the response, any variablesReference previously associated with the updated variable, and those of its children, are no longer valid.