pub struct VariablePresentationHint {
pub attributes: Option<Vec<VariablePresentationHintAttributes>>,
pub kind: Option<VariablePresentationHintKind>,
pub lazy: Option<bool>,
pub visibility: Option<VariablePresentationHintVisibility>,
}Expand description
Properties of a variable that can be used to determine how to render the variable in the UI.
Fields
attributes: Option<Vec<VariablePresentationHintAttributes>>Set of attributes represented as an array of strings. Before introducing additional values, try to use the listed values.
kind: Option<VariablePresentationHintKind>The kind of variable. Before introducing additional values, try to use the listed values.
lazy: Option<bool>If true, clients can present the variable with a UI that supports a specific gesture to trigger its evaluation.
This mechanism can be used for properties that require executing code when retrieving their value and where the code execution can be expensive and/or produce side-effects. A typical example are properties based on a getter function.
Please note that in addition to the lazy flag, the variable’s variablesReference is expected to refer to a variable that will provide the value through another variable request.
visibility: Option<VariablePresentationHintVisibility>Visibility of variable. Before introducing additional values, try to use the listed values.